@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.5.13"
+__version__ = "0.5.14"
 
 
 import datetime
@@ -101,11 +101,14 @@ class CuJiraX:
 
             # Import Test cases
             if import_testcase:
-                exists, new = self._split_elements_to_exist_and_new(
-                    elements=f.elements, 
-                    j=self.jira, 
-                    ignore_duplicate=ignore_duplicate
-                )
+                try:
+                    exists, new = self._split_elements_to_exist_and_new(
+                        elements=f.elements, 
+                        j=self.jira, 
+                        ignore_duplicate=ignore_duplicate
+                    )
+                except ValueError as e:
+                    raise type(e)(f"{f.uri}: {str(e)}") from e
                 
                 tests = [str(n) for n in map(
                     lambda x: self._update_description_if_exist(x,self.jira), exists)]
